@@ -171,8 +171,10 @@ class RCConfig:
             self.dense_dropout = config['Architecture'].getfloat('Dense_Dropout')
             try:
                 self.mc_dropout = config['Architecture'].getboolean('MC_Dropout')
+                self.dropout_training_mode = None if not self.mc_dropout else True
             except KeyError:
                 self.mc_dropout = False
+                self.dropout_training_mode = None
 
             # If needed, weight classes
             self.use_weights = config['ClassWeights'].getboolean('UseWeights')
@@ -636,7 +638,7 @@ class RCNet:
         return_sequences = True if self.config.n_recurrent > 1 else False
         # Input dropout
         if not np.isclose(self.config.input_dropout, 0.0):
-            x = Dropout(self.config.input_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+            x = Dropout(self.config.input_dropout, seed=self.config.seed)(x, training=self.config.dropout_training_mode)
         else:
             x = inputs
         # First convolutional/recurrent layer
@@ -661,7 +663,8 @@ class RCNet:
                 # Standard batch normalization layer
                 x = BatchNormalization()(x)
             # Add dropout
-            x = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+            x = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x,
+                                                                              training=self.config.dropout_training_mode)
             # First recurrent layer already added
             self._current_recurrent = 1
         else:
@@ -684,7 +687,8 @@ class RCNet:
                 raise ValueError('Unknown pooling method')
             # Add dropout (drops whole features)
             if not np.isclose(self.config.conv_dropout, 0.0):
-                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x,
+                                                                             training=self.config.dropout_training_mode)
             # Add layer
             # Standard convolutional layer
             x = Conv1D(filters=self.config.conv_units[i], kernel_size=self.config.conv_filter_size[i],
@@ -732,7 +736,8 @@ class RCNet:
                 raise ValueError('Unknown pooling method')
             # Add dropout (drops whole features)
             if not np.isclose(self.config.conv_dropout, 0.0):
-                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x,
+                                                                             training=self.config.dropout_training_mode)
 
         # Recurrent layers
         for i in range(self._current_recurrent, self.config.n_recurrent):
@@ -745,7 +750,8 @@ class RCNet:
                 # Standard batch normalization layer
                 x = BatchNormalization()(x)
             # Add dropout
-            x = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+            x = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x,
+                                                                              training=self.config.dropout_training_mode)
 
         # Dense layers
         for i in range(0, self.config.n_dense):
@@ -756,7 +762,8 @@ class RCNet:
                 # Standard batch normalization layer
                 x = BatchNormalization()(x)
             x = Activation(self.config.dense_activation)(x)
-            x = Dropout(self.config.dense_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+            x = Dropout(self.config.dense_dropout, seed=self.config.seed)(x,
+                                                                          training=self.config.dropout_training_mode)
 
         # Output layer for binary classification
         x = Dense(1,
@@ -786,7 +793,7 @@ class RCNet:
         return_sequences = True if self.config.n_recurrent > 1 else False
         # Input dropout
         if not np.isclose(self.config.input_dropout, 0.0):
-            x = Dropout(self.config.input_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+            x = Dropout(self.config.input_dropout, seed=self.config.seed)(x, training=self.config.dropout_training_mode)
         else:
             x = inputs
         # First convolutional/recurrent layer
@@ -811,7 +818,9 @@ class RCNet:
                 self._current_bn = self._current_bn + 1
             # Add dropout
             if not np.isclose(self.config.recurrent_dropout, 0.0):
-                x = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.recurrent_dropout,
+                            seed=self.config.seed)(x,
+                                                   training=self.config.dropout_training_mode)
             # First recurrent layer already added
             self._current_recurrent = self._current_recurrent + 1
         else:
@@ -836,7 +845,8 @@ class RCNet:
                 raise ValueError('Unknown pooling method')
             # Add dropout (drops whole features)
             if not np.isclose(self.config.conv_dropout, 0.0):
-                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x,
+                                                                             training=self.config.dropout_training_mode)
             # Add layer
             x = self._add_rc_conv1d(x, units=self.config.conv_units[i], kernel_size=self.config.conv_filter_size[i],
                                     dilation_rate=self.config.conv_dilation[i],
@@ -883,7 +893,8 @@ class RCNet:
                 raise ValueError('Unknown pooling method')
             # Add dropout (drops whole features)
             if not np.isclose(self.config.conv_dropout, 0.0):
-                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.conv_dropout, seed=self.config.seed)(x,
+                                                                             training=self.config.dropout_training_mode)
 
         # Recurrent layers
         for i in range(self._current_recurrent, self.config.n_recurrent):
@@ -898,7 +909,9 @@ class RCNet:
                 self._current_bn = self._current_bn + 1
             # Add dropout
             if not np.isclose(self.config.recurrent_dropout, 0.0):
-                x = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.recurrent_dropout,
+                            seed=self.config.seed)(x,
+                                                   training=self.config.dropout_training_mode)
             self._current_recurrent = self._current_recurrent + 1
 
         # Dense layers
@@ -913,7 +926,9 @@ class RCNet:
                 x = BatchNormalization()(x)
             x = Activation(self.config.dense_activation)(x)
             if not np.isclose(self.config.dense_dropout, 0.0):
-                x = Dropout(self.config.dense_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.dense_dropout,
+                            seed=self.config.seed)(x,
+                                                   training=self.config.dropout_training_mode)
 
         # Output layer for binary classification
         if self.config.n_dense == 0:
@@ -948,8 +963,12 @@ class RCNet:
         return_sequences = True if self.config.n_recurrent > 1 else False
         # Input dropout
         if not np.isclose(self.config.input_dropout, 0.0):
-            x_fwd = Dropout(self.config.input_dropout, seed=self.config.seed)(x_fwd, training=self.config.mc_dropout)
-            x_rc = Dropout(self.config.input_dropout, seed=self.config.seed)(x_rc, training=self.config.mc_dropout)
+            x_fwd = Dropout(self.config.input_dropout,
+                            seed=self.config.seed)(x_fwd,
+                                                   training=self.config.dropout_training_mode)
+            x_rc = Dropout(self.config.input_dropout,
+                           seed=self.config.seed)(x_rc,
+                                                  training=self.config.dropout_training_mode)
         # First convolutional/recurrent layer
         if self.config.n_conv > 0:
             # Convolutional layers will always be placed before recurrent ones
@@ -979,10 +998,12 @@ class RCNet:
                 self._current_bn = self._current_bn + 1
             # Add dropout
             if not np.isclose(self.config.recurrent_dropout, 0.0):
-                x_fwd = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x_fwd,
-                                                                                      training=self.config.mc_dropout)
-                x_rc = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x_rc,
-                                                                                     training=self.config.mc_dropout)
+                x_fwd = Dropout(self.config.recurrent_dropout,
+                                seed=self.config.seed)(x_fwd,
+                                                       training=self.config.dropout_training_mode)
+                x_rc = Dropout(self.config.recurrent_dropout,
+                               seed=self.config.seed)(x_rc,
+                                                      training=self.config.dropout_training_mode)
             # First recurrent layer already added
             self._current_recurrent = 1
         else:
@@ -1011,8 +1032,12 @@ class RCNet:
                 raise ValueError('Unknown pooling method')
             # Add dropout (drops whole features)
             if not np.isclose(self.config.conv_dropout, 0.0):
-                x_fwd = Dropout(self.config.conv_dropout, seed=self.config.seed)(x_fwd, training=self.config.mc_dropout)
-                x_rc = Dropout(self.config.conv_dropout, seed=self.config.seed)(x_rc, training=self.config.mc_dropout)
+                x_fwd = Dropout(self.config.conv_dropout,
+                                seed=self.config.seed)(x_fwd,
+                                                       training=self.config.dropout_training_mode)
+                x_rc = Dropout(self.config.conv_dropout,
+                               seed=self.config.seed)(x_rc,
+                                                      training=self.config.dropout_training_mode)
             # Add layer
             # Reverse-complement convolutional layer
             x_fwd, x_rc = self._add_siam_conv1d(x_fwd, x_rc, units=self.config.conv_units[i],
@@ -1074,8 +1099,10 @@ class RCNet:
                 raise ValueError('Unknown pooling method')
             # Add dropout (drops whole features)
             if not np.isclose(self.config.conv_dropout, 0.0):
-                x_fwd = Dropout(self.config.conv_dropout, seed=self.config.seed)(x_fwd, training=self.config.mc_dropout)
-                x_rc = Dropout(self.config.conv_dropout, seed=self.config.seed)(x_rc, training=self.config.mc_dropout)
+                x_fwd = Dropout(self.config.conv_dropout,
+                                seed=self.config.seed)(x_fwd, training=self.config.dropout_training_mode)
+                x_rc = Dropout(self.config.conv_dropout,
+                               seed=self.config.seed)(x_rc, training=self.config.dropout_training_mode)
 
         # Recurrent layers
         for i in range(self._current_recurrent, self.config.n_recurrent):
@@ -1091,10 +1118,10 @@ class RCNet:
                 self._current_bn = self._current_bn + 1
             # Add dropout
             if not np.isclose(self.config.recurrent_dropout, 0.0):
-                x_fwd = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x_fwd,
-                                                                                      training=self.config.mc_dropout)
-                x_rc = Dropout(self.config.recurrent_dropout, seed=self.config.seed)(x_rc,
-                                                                                     training=self.config.mc_dropout)
+                x_fwd = Dropout(self.config.recurrent_dropout,
+                                seed=self.config.seed)(x_fwd, training=self.config.dropout_training_mode)
+                x_rc = Dropout(self.config.recurrent_dropout,
+                               seed=self.config.seed)(x_rc, training=self.config.dropout_training_mode)
 
         # Output layer for binary classification
         if self.config.n_dense == 0:
@@ -1107,7 +1134,8 @@ class RCNet:
                 # Batch normalization layer
                 x = BatchNormalization()(x)
             x = Activation(self.config.dense_activation)(x)
-            x = Dropout(self.config.dense_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+            x = Dropout(self.config.dense_dropout,
+                        seed=self.config.seed)(x, training=self.config.dropout_training_mode)
             for i in range(1, self.config.n_dense):
                 x = Dense(self.config.dense_units[i],
                           kernel_initializer=self.config.initializers["dense"],
@@ -1116,7 +1144,8 @@ class RCNet:
                     # Batch normalization layer
                     x = BatchNormalization()(x)
                 x = Activation(self.config.dense_activation)(x)
-                x = Dropout(self.config.dense_dropout, seed=self.config.seed)(x, training=self.config.mc_dropout)
+                x = Dropout(self.config.dense_dropout,
+                            seed=self.config.seed)(x, training=self.config.dropout_training_mode)
             # Output layer for binary classification
             x = Dense(1,
                       kernel_initializer=self.config.initializers["out"],
